@@ -1,13 +1,11 @@
 # Copyright 2019 Cognite AS
 import logging
 import os
-import sys
 import time
 from collections import namedtuple
 from typing import Callable
 
 import certifi
-import deprecation
 import grpc
 from grpc._channel import (
     _InactiveRpcError,
@@ -19,27 +17,19 @@ from grpc._channel import (
 
 if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic._api.file import FileAPI
-    from cognite.seismic._api.file_seismic import FileSeismicAPI
     from cognite.seismic._api.job import JobAPI
     from cognite.seismic._api.partition import PartitionAPI
     from cognite.seismic._api.seismics import SeismicAPI
     from cognite.seismic._api.seismicstores import SeismicStoreAPI
-    from cognite.seismic._api.slice import SliceAPI
-    from cognite.seismic._api.slab import SlabAPI
     from cognite.seismic._api.survey import SurveyAPI
-    from cognite.seismic._api.survey_v1 import SurveyV1API
-    from cognite.seismic._api.time_slice import TimeSliceAPI
-    from cognite.seismic._api.trace import TraceAPI
-    from cognite.seismic._api.volume import VolumeAPI
-    from cognite.seismic._api.volume_seismic import VolumeSeismicAPI
+    from cognite.seismic._api.traces import TracesAPI
     from cognite.seismic.data_classes.errors import SeismicServiceError, _from_grpc_error
     from cognite.seismic.protos import ingest_service_pb2_grpc as ingest_serv
     from cognite.seismic.protos import query_service_pb2_grpc as query_serv
     from cognite.seismic.protos.v1 import seismic_service_pb2_grpc as seismic_serv
 
-# The maximum number of retries
-_MAX_RETRIES_BY_CODE = {
-    grpc.StatusCode.INTERNAL: 1,
+# The maximum number of call attempts including both the initial call and any retries
+_MAX_ATTEMPTS_BY_CODE = {
     grpc.StatusCode.ABORTED: 3,
     grpc.StatusCode.UNAVAILABLE: 5,
     grpc.StatusCode.DEADLINE_EXCEEDED: 5,
@@ -54,27 +44,28 @@ logger = logging.getLogger(__name__)
 
 def with_retry(f, transactional=False):
     def wraps(*args, **kwargs):
-        retries = 0
+        attempts = 0
         while True:
             try:
                 return f(*args, **kwargs)
             except _InactiveRpcError as e:
+                attempts += 1
                 code = e.code()
 
-                max_retries = _MAX_RETRIES_BY_CODE.get(code)
-                if max_retries is None or transactional and code == grpc.StatusCode.ABORTED:
+                max_attempts = _MAX_ATTEMPTS_BY_CODE.get(code)
+                if max_attempts is None or transactional and code == grpc.StatusCode.ABORTED:
                     raise
 
-                if retries > max_retries:
-                    e = SeismicServiceError()
-                    e.status = grpc.StatusCode.UNAVAILABLE
-                    e.message = "maximum number of retries exceeded"
-                    raise e
+                if attempts > max_attempts:
+                    seismic_error = SeismicServiceError()
+                    seismic_error.status = grpc.StatusCode.UNAVAILABLE
+                    seismic_error.message = "maximum number of retries exceeded"
+                    seismic_error.source = e
+                    raise seismic_error
 
-                backoff = min(_MIN_SLEEPING * 2 ** retries, _MAX_SLEEPING)
+                backoff = min(_MIN_SLEEPING * 2**attempts, _MAX_SLEEPING)
                 logger.info("sleeping %r for %r before retrying failed request...", backoff, code)
 
-                retries += 1
                 time.sleep(backoff)
 
     return wraps
@@ -162,25 +153,25 @@ class CogniteSeismicClient:
 
 
     Args:
-        api_key (Optional[str]): An API key. Equivalent to setting the COGNITE_API_KEY environment variable.
-        base_url (Optional[str]): The url to connect to. Defaults to :code:`api.cognitedata.com`.
-        port (Optional[int]): The port to connect to. Defaults to 443.
-        custom_root_cert (Optional[str]): A custom root certificate for SSL connections. Should not need to be used by general users.
-        insecure (bool): If true, will attempt to connect without SSL. Should not be used by general users.
+        api_key (str, optional): An API key. Equivalent to setting the :code:`COGNITE_API_KEY` environment variable.
+        base_url (str, optional): The url to connect to. Defaults to :code:`api.cognitedata.com`.
+        port (int, optional): The port to connect to. Defaults to 443.
+        custom_root_cert (str, optional):
+            A custom root certificate for SSL connections. Should not need to be used by general users.
         project (str): The name of the project to call API endpoints against.
         no_retries (bool): If true, will not automatically retry failed requests.
         max_message_size_MB (int): The max message size of gRPC replies. Defaults to 10.
-        oidc_token (Optional[str | Callable[[], str]]): If specified, will attempt to connect to the seismic service using an OIDC token. This should be either a string or a callable.
+        oidc_token (str | function() -> str, optional):
+            If specified, will attempt to connect to the seismic service using an OIDC token.
+            This should be either a string or a callable resolving to a string.
     """
 
     def __init__(
         self,
         api_key=None,
         base_url=None,
-        port=None,
         custom_root_cert=None,
         *,
-        insecure=False,
         project=None,
         no_retries=False,
         max_message_size_MB=10,
@@ -190,9 +181,6 @@ class CogniteSeismicClient:
         self.api_key = api_key or os.getenv("COGNITE_API_KEY")
         self.project = project or os.getenv("COGNITE_PROJECT")
 
-        if port is not None or insecure:
-            logger.warning("The port and insecure params are deprecated. Please include them in the base_url.")
-
         if base_url is not None:
             parsed_url = parse_url_parameter(base_url)
             self.target = parsed_url.target
@@ -202,14 +190,12 @@ class CogniteSeismicClient:
             self.is_insecure = False
 
         if self.project is None:
-            if oidc_token is not None:
-                raise ValueError(
-                    "CDF project name must be supplied when using OIDC tokens. Please set the project name with CogniteSeismicClient(project='') or with environment variable COGNITE_PROJECT=''"
-                )
-            else:
-                logger.warning(
-                    "Undefined project name is deprecated behaviour. Please set the project name with CogniteSeismicClient(project='') or with environment variable COGNITE_PROJECT=''"
-                )
+            raise ValueError(
+                "CDF project name must be supplied. \
+                Please set the project name with \
+                CogniteSeismicClient(project='') or with an environment \
+                variable COGNITE_PROJECT=''"
+            )
 
         if custom_root_cert is None:
             root_certs = certifi.contents().encode()
@@ -262,21 +248,10 @@ You must provide at least one of the following:
             decorate_with_retries(self.query, self.ingestion, self.seismicstub)
         decorate_with_wrapped_rpc_errors(self.query, self.ingestion, self.seismicstub)
 
-        self.survey = SurveyAPI(self.query, self.ingestion)
-        self.file = FileAPI(self.query, self.ingestion)
-        self.trace = TraceAPI(self.query)
-        self.slice = SliceAPI(self.query)
-        self.slab = SlabAPI(self.query, self.file)
-        self.volume = VolumeAPI(self.query, self.ingestion)
-        self.time_slice = TimeSliceAPI(self.query)
-        self.job = JobAPI(self.ingestion)
-        self.survey_v1 = SurveyV1API(self.seismicstub, self.survey)
-        self.volume_seismic = VolumeSeismicAPI(self.seismicstub, self.ingestion)
+        self.job = JobAPI(self.seismicstub)
+        self.survey = SurveyAPI(self.seismicstub)
+        self.traces = TracesAPI(self.seismicstub, self.ingestion)
         self.partition = PartitionAPI(self.seismicstub, self.ingestion)
-        # The duplicated seismic/seismics is for making the rename backwards compatible.
-        # The singular form is the one that we expect to keep after a breaking release.
-        self.seismic = SeismicAPI(self.seismicstub, self.ingestion)
-        self.seismics = SeismicAPI(self.seismicstub, self.ingestion)
-        self.seismicstore = SeismicStoreAPI(self.seismicstub, self.ingestion)
-        self.seismicstores = SeismicStoreAPI(self.seismicstub, self.ingestion)
-        self.file_seismic = FileSeismicAPI(self.seismicstub, self.ingestion, self)
+        self.seismic = SeismicAPI(self)
+        self.seismicstore = SeismicStoreAPI(self)
+        self.file = FileAPI(self.seismicstub, self.ingestion)
